==> hoogle-5.0.13-1-i686.pkg.tar.xz: usr/share/haskell/register/hoogle.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hoogle
version: 5.0.13
id: hoogle-5.0.13-9K8Zk0eExAfaE9tM9qFaF
key: hoogle-5.0.13-9K8Zk0eExAfaE9tM9qFaF
license: BSD3
copyright: Neil Mitchell 2004-2017
maintainer: Neil Mitchell <ndmitchell@gmail.com>
homepage: http://hoogle.haskell.org/
synopsis: Haskell API Search
description:
    Hoogle is a Haskell API search engine, which allows you to
    search many standard Haskell libraries by either function name,
    or by approximate type signature.
category: Development
author: Neil Mitchell <ndmitchell@gmail.com>
exposed: True
exposed-modules:
    Hoogle
hidden-modules: Paths_hoogle Action.CmdLine Action.Generate
                Action.Search Action.Server Action.Test Input.Cabal Input.Download
                Input.Haddock Input.Item Input.Reorder Input.Set Input.Settings
                Output.Items Output.Names Output.Tags Output.Types Query
                General.Conduit General.IString General.Log General.Store
                General.Str General.Template General.Timing General.Util
                General.Web
abi: bd237663b15d2064fb4bfaa2d9fc921d
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/hoogle-5.0.13
library-dirs: /usr/lib/ghc-8.0.2/site-local/hoogle-5.0.13
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/hoogle
hs-libraries: HShoogle-5.0.13-9K8Zk0eExAfaE9tM9qFaF
include-dirs: /usr/lib/ghc-8.0.2/site-local/hoogle-5.0.13/include
includes:
    include.h
depends:
    QuickCheck-2.10.0.1-ALuGysu7txTB2VnkPyDuTq
    aeson-1.1.2.0-3Yc3xmkAyKHC7Vn5OXDFOk base-4.9.1.0 binary-0.8.3.0
    bytestring-0.10.8.1 cmdargs-0.10.17-gTr0lzwrHbBcQQ47pfTGo
    conduit-1.2.11-GzxQexWP3ouJXox0rAqJ5D
    conduit-extra-1.1.16-5YILVd78SGn9wwYaAO3g7W
    connection-0.2.8-DB0ivNtmC6fCU1sKC6PGf8 containers-0.5.7.1
    deepseq-1.4.2.0 directory-1.3.0.0
    extra-1.5.3-D0CTSfwIrg4DdcYZmgSnz1 filepath-1.4.1.1
    haskell-src-exts-1.19.1-7Ymk4sexwB7KzlRpbPSyAR
    http-conduit-2.2.3.2-CRy4tYu0ljJKEchcyy6apj
    http-types-0.9.1-IqlxYYwrFhNBj6J7ATsByJ
    js-flot-0.8.3-FFINNwUg9vmHMMWQsN8uhg
    js-jquery-3.2.1-GtxtZ651RlV17366fNzcXt
    mmap-0.5.9-IOUZUUQXpolHbXRgP4hWIu
    network-2.6.3.2-IsLM4TXcLoRI0fmmBYVyQz
    network-uri-2.6.1.0-GzRvaV3udR3JtWfa3CLYOw
    old-locale-1.0.0.7-KGBP1BSKxH5GCm0LnZP04j process-1.4.3.0
    process-extras-0.7.2-1XtyjVaR6fvEQf2ThThDxf
    resourcet-1.1.9-DJf1ANdxSraDnKUpiOoSOA
    tar-0.5.0.3-60pC6grTbvG2zWoTgfDWBJ template-haskell-2.11.1.0
    text-1.2.2.2-3ENqlljngKa6xj1Go2fVWq time-1.6.0.1
    transformers-0.5.2.0 uniplate-1.6.12-BnRcpBOCdUXBfQOzOuZrJE
    utf8-string-1.0.1.1-1DpjxLeTvGg7ttZZojxJR5
    vector-0.12.0.1-692PQMDMB6pIQ1uGwefDcQ
    wai-3.2.1.1-8mpSdlQN10CC3im2R8JJP4
    wai-logger-2.3.0-JsYl94dk2DB2fjpqHDT8kd
    warp-3.2.13-3b9ahS01zRZ7bE17bwbPRa
    warp-tls-3.2.4-IsMM5MShy8xIZ99P3TB8bp
    zlib-0.6.1.2-GcLmGV5PElZD6CJvjR9umm
haddock-interfaces: /usr/share/doc/hoogle/html/hoogle.haddock
haddock-html: /usr/share/doc/hoogle/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> hoogle-5.0.13-7-i686.pkg.tar.xz: usr/share/haskell/register/hoogle.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hoogle
version: 5.0.13
id: hoogle-5.0.13-KwtefrymB9S37EpHyx7MoM
key: hoogle-5.0.13-KwtefrymB9S37EpHyx7MoM
license: BSD3
copyright: Neil Mitchell 2004-2017
maintainer: Neil Mitchell <ndmitchell@gmail.com>
homepage: http://hoogle.haskell.org/
synopsis: Haskell API Search
description:
    Hoogle is a Haskell API search engine, which allows you to
    search many standard Haskell libraries by either function name,
    or by approximate type signature.
category: Development
author: Neil Mitchell <ndmitchell@gmail.com>
exposed: True
exposed-modules:
    Hoogle
hidden-modules: Paths_hoogle Action.CmdLine Action.Generate
                Action.Search Action.Server Action.Test Input.Cabal Input.Download
                Input.Haddock Input.Item Input.Reorder Input.Set Input.Settings
                Output.Items Output.Names Output.Tags Output.Types Query
                General.Conduit General.IString General.Log General.Store
                General.Str General.Template General.Timing General.Util
                General.Web
abi: c23d6d0db6822042c57d52d0bf72a541
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/hoogle-5.0.13
library-dirs: /usr/lib/ghc-8.0.2/site-local/hoogle-5.0.13
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/hoogle
hs-libraries: HShoogle-5.0.13-KwtefrymB9S37EpHyx7MoM
include-dirs: /usr/lib/ghc-8.0.2/site-local/hoogle-5.0.13/include
includes:
    include.h
depends:
    QuickCheck-2.10.0.1-ALuGysu7txTB2VnkPyDuTq
    aeson-1.1.2.0-8R262j8BseM7FTnCfGfbwu base-4.9.1.0 binary-0.8.3.0
    bytestring-0.10.8.1 cmdargs-0.10.17-gTr0lzwrHbBcQQ47pfTGo
    conduit-1.2.11-GzxQexWP3ouJXox0rAqJ5D
    conduit-extra-1.1.16-ENJUyud795q910vrFDK54q
    connection-0.2.8-CGiATO2j5R42aJ03vgOGSu containers-0.5.7.1
    deepseq-1.4.2.0 directory-1.3.0.0
    extra-1.5.3-D0CTSfwIrg4DdcYZmgSnz1 filepath-1.4.1.1
    haskell-src-exts-1.19.1-7Ymk4sexwB7KzlRpbPSyAR
    http-conduit-2.2.3.2-3qniP0qDmgZFFr3LuPKHvi
    http-types-0.9.1-IqlxYYwrFhNBj6J7ATsByJ
    js-flot-0.8.3-FFINNwUg9vmHMMWQsN8uhg
    js-jquery-3.2.1-GtxtZ651RlV17366fNzcXt
    mmap-0.5.9-IOUZUUQXpolHbXRgP4hWIu
    network-2.6.3.2-IsLM4TXcLoRI0fmmBYVyQz
    network-uri-2.6.1.0-GzRvaV3udR3JtWfa3CLYOw
    old-locale-1.0.0.7-KGBP1BSKxH5GCm0LnZP04j process-1.4.3.0
    process-extras-0.7.2-1XtyjVaR6fvEQf2ThThDxf
    resourcet-1.1.9-DJf1ANdxSraDnKUpiOoSOA
    tar-0.5.0.3-60pC6grTbvG2zWoTgfDWBJ template-haskell-2.11.1.0
    text-1.2.2.2-3ENqlljngKa6xj1Go2fVWq time-1.6.0.1
    transformers-0.5.2.0 uniplate-1.6.12-A02jTsyQmCWKBCl3BhcKvP
    utf8-string-1.0.1.1-1DpjxLeTvGg7ttZZojxJR5
    vector-0.12.0.1-692PQMDMB6pIQ1uGwefDcQ
    wai-3.2.1.1-8mpSdlQN10CC3im2R8JJP4
    wai-logger-2.3.0-JsYl94dk2DB2fjpqHDT8kd
    warp-3.2.13-2zIfvy7PaU822kbwwTyJQq
    warp-tls-3.2.4-7GPqskZXYzlJP5JHfsbJYd
    zlib-0.6.1.2-GcLmGV5PElZD6CJvjR9umm
haddock-interfaces: /usr/share/doc/hoogle/html/hoogle.haddock
haddock-html: /usr/share/doc/hoogle/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
